from typing import List

from Jce_b import JceWriter, JceReader
from pydantic import BaseModel, Field

from AndroidQQ import log
from AndroidQQ.struct.Avatarlnfo import DestQQHeadInfo


# struct AvatarInfo;


class QQHeadUrlReq(BaseModel):
    """QQ头像网址请求"""
    destUserInfo: List[DestQQHeadInfo] = []
    dstUsrType: int = Field(0, description="目标用户类型")
    myUin: int = 0

    def writeTo(self):
        destUserInfo_list = [info.writeTo() for info in self.destUserInfo]
        jce = JceWriter()
        jce.write_int64(self.myUin, 0)
        jce.write_jce_struct_list(destUserInfo_list, 1)
        jce.write_int32(self.dstUsrType, 2)
        return jce.bytes()


if __name__ == '__main__':
    DestInfo = DestQQHeadInfo(phoneNum="+8612131313131")
    log.info(QQHeadUrlReq(destUserInfo=[DestInfo]).writeTo().hex())
    pass



from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader


class s_arkshare(IJceStruct):
    ark_content: str = ""
    ark_id: str = ""
    view_id: str = ""

    def read_from(self, reader: JceReader) -> None:
        self.ark_id = reader.read_any(0)
        self.view_id = reader.read_any(1)
        self.ark_content = reader.read_any(2)
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass



# 登录相关
import datetime
import time

from AndTools import pack_b, TEA, pack_u, get_md5

from AndroidQQ import log
from AndroidQQ.struct.Tlv import TLV
from AndroidQQ.struct.Tlv_res import Un_Tlv
from AndroidQQ.struct.head import Pack_Head_login, Pack_
from AndroidQQ.utils.ecdh import get_ecdh


def login(info, **kwargs):
    """登录包"""
    info.uin = kwargs.get('uin', 0)
    info.password = kwargs.get('password', '')
    info.Guid = kwargs.get('Guid', None)
    if not info.Guid:
        info.Guid = bytes.fromhex('69 4C 16 6C BA 92 7C CD C5 32 73 13 79 FF 74 DA')

    # log.info('GUid', info.Guid.hex())
    public_key, share_key = get_ecdh()
    info.key_Pubkey = public_key
    info.share_key = share_key
    _tlv = TLV(info)
    pack = pack_b()
    if info.device.client_type == 'Watch':
        # 手表协议
        methods = [
            _tlv.T018(),
            _tlv.T001(),
            _tlv.T106(),  # 必须
            _tlv.T116(),  # 必须
            _tlv.T100(5, 16, 0, 33820864),  # 必须
            _tlv.T107(),  # 必须
            _tlv.T142(),  # 必须
            _tlv.T144(),  # 必须
            _tlv.T145(),  # 必须
            _tlv.T147(),
            _tlv.T16A(),  # 必须
            _tlv.T154(),
            _tlv.T141(),
            _tlv.T008(),
            _tlv.T187(),
            _tlv.T188(),
            _tlv.T194(),
            _tlv.T191('00'),
            _tlv.T202(),
            _tlv.T177(),
            _tlv.T516(),
            _tlv.T521(115),
            _tlv.T318(),  # s
            # _tlv.T544
        ]
    elif info.device.client_type == 'QQ_old':

        # info.key_Pubkey = bytes.fromhex(
        #     '04 48 83 C6 0D 32 82 3D 7C 5B 05 80 16 8B 4B 6A 56 46 E3 78 2B 6D C6 82 9D 5D 36 10 BD AF 07 60 DC 31 AF 8C A4 BC C5 B2 B2 82 69 3C F8 90 C2 13 31 28 9F FF 12 3A 84 16 D1 3A 36 CA 59 04 26 96 F3')  #
        # info.share_key = bytes.fromhex('D8 5A 46 FF E3 6C 56 2C 8A 3A 4E E7 AF B2 25 77')
        # info.key_rand = bytes.fromhex('B6153247AA194EB9991CBDCE4A4C234C')
        # info.key_tgtgt = bytes.fromhex('B6 15 32 47 AA 19 4E B9 99 1C BD CE 4A 4C 23 4C')
        methods = [
            _tlv.T018(),
            _tlv.T001(),
            _tlv.T106(),  # 必须
            _tlv.T116(),  # 必须
            _tlv.T100(15, 16, 0, 34869472),  # 必须
            _tlv.T107(),  # 必须
            _tlv.T142(),  # 必须
            _tlv.T144(),  # 必须
            _tlv.T145(),  # 必须
            _tlv.T147(),
            _tlv.T154(),
            _tlv.T141(),
            _tlv.T008(),
            _tlv.T511(),
            _tlv.T187(),
            _tlv.T188(),
            _tlv.T191('82'),
            _tlv.T202(),
            _tlv.T177(),
            _tlv.T516(),
            _tlv.T521(0),
            _tlv.T525('00 01 05 36 00 02 01 00'),
            # _tlv.T544(),
            # _tlv.T545(),
            # _tlv.T548(),

        ]


    else:
        # 默认普通QQ
        info.key_Pubkey = bytes.fromhex(
            '04 6F 9E D9 8C FB 8B 92 73 73 69 6E B7 CA 40 A5 BE 28 84 D0 EF EC D5 96 84 C2 E9 14 50 8F A9 7B 20 9F F2 4E 35 5E D3 92 21 53 ED 9A F1 8F 14 D0 02 73 E0 62 AD C3 A3 79 21 A2 6A 66 19 D2 A5 C7 E3')  #
        info.share_key = bytes.fromhex('0E6F09415FC0A5CCD040AFA92EBE3EB0')
        info.key_rand = bytes.fromhex('944C10A69E2A5E4CEEF08512BA3B39FE')
        info.key_tg = bytes.fromhex('AD 07 ED 80 67 75 BB F7 FD C4 A8 D5 41 5E 73 EA')
        info.Guid = bytes.fromhex('9b6be0653a356f4fac89926f3f1ceb7e')
        # 手机协议-
        methods = [
            _tlv.T018,
            _tlv.T001,
            _tlv.T106,
            _tlv.T116,
            _tlv.T100,
            _tlv.T107,
            _tlv.T142,
            _tlv.T144,
            _tlv.T145,
            _tlv.T147,
            _tlv.T154,
            _tlv.T141,
            _tlv.T008,
            _tlv.T511,
            _tlv.T187,
            _tlv.T188,
            _tlv.T191,
            _tlv.T177,
            _tlv.T516,
            _tlv.T521,
            _tlv.T525
        ]

        # pass

    pack.add_Hex('00 09')
    pack.add_int(len(methods), 2)  # 数量

    for method_result in methods:
        pack.add_bin(method_result)
    _data = pack.get_bytes()
    log.info(_data.hex())

    data = TEA.encrypt(_data, info.share_key)

    # 头部
    pack = pack_b()
    pack.add_Hex('1F 41')
    pack.add_Hex('08 10')
    pack.add_Hex('00 01')
    pack.add_int(int(info.uin))  # Uin_bytes
    if info.device.client_type == 'Watch':
        pack.add_Hex('03 07 00 00 00 00 02 00 00 00 00 00 00 00 00')
        pack.add_Hex('01 01')
        pack.add_bin(info.key_rand)  # 不是key
        pack.add_Hex('01 02')

    else:
        # 默认普通QQ
        pack.add_Hex('03 87 00 00 00 00 02 00 00 00 00 00 00 00 00')
        pack.add_Hex('02 01')
        pack.add_bin(info.key_rand)  # 不是key
        pack.add_Hex('01 31')
        pack.add_Hex('00 01')

    pack.add_body(info.key_Pubkey, 2)

    pack.add_bin(data)
    data = pack.get_bytes()

    pack.empty()  # 包裹
    pack.add_Hex('02')
    pack.add_body(data, 2, add_len=4)

    pack.add_Hex('03')
    data = pack.get_bytes()
    # 头部
    data = Pack_Head_login(info, 'wtlogin.login', data)

    data = Pack_(info, data=data, encryption=2, Types=10, sso_seq=4)

    return data


def login_H(info, **kwargs):
    """混合登录包"""

    if not info.Guid:
        info.Guid = bytes.fromhex('69 4C 16 6C BA 92 7C CD C5 32 73 13 79 FF 74 DA')

    # log.info('GUid', info.Guid.hex())
    public_key, share_key = get_ecdh()
    info.key_Pubkey = public_key
    info.share_key = share_key
    _tlv = TLV(info)
    pack = pack_b()
    methods = [
        _tlv.T018(),
        _tlv.T001(),
        _tlv.T106(),  # 必须
        _tlv.T116(),  # 必须
        _tlv.T100(15, 16, 0, 34869472),  # 必须
        _tlv.T107(),  # 必须
        _tlv.T142(),  # 必须
        _tlv.T144(),  # 必须
        _tlv.T145(),  # 必须
        _tlv.T147(),
        _tlv.T154(),
        _tlv.T141(),
        _tlv.T008(),
        _tlv.T511(),
        _tlv.T187(),
        _tlv.T188(),
        _tlv.T191('82'),
        _tlv.T202(),
        _tlv.T177(),
        _tlv.T516(),
        _tlv.T521(0),
        _tlv.T525('00 01 05 36 00 02 01 00'),
    ]

    pack.add_Hex('00 09')
    pack.add_int(len(methods), 2)  # 数量

    for method_result in methods:
        pack.add_bin(method_result)
    _data = pack.get_bytes()
    log.info(_data.hex())

    data = TEA.encrypt(_data, info.share_key)

    # 头部
    pack = pack_b()
    pack.add_Hex('1F 41')
    pack.add_Hex('08 10')
    pack.add_Hex('00 01')
    pack.add_int(int(info.uin))  # Uin_bytes
    if info.device.client_type == 'Watch':
        pack.add_Hex('03 07 00 00 00 00 02 00 00 00 00 00 00 00 00')
        pack.add_Hex('01 01')
        pack.add_bin(info.key_rand)  # 不是key
        pack.add_Hex('01 02')

    else:
        # 默认普通QQ
        pack.add_Hex('03 87 00 00 00 00 02 00 00 00 00 00 00 00 00')
        pack.add_Hex('02 01')
        pack.add_bin(info.key_rand)  # 不是key
        pack.add_Hex('01 31')
        pack.add_Hex('00 01')

    pack.add_body(info.key_Pubkey, 2)

    pack.add_bin(data)
    data = pack.get_bytes()

    pack.empty()  # 包裹
    pack.add_Hex('02')
    pack.add_body(data, 2, add_len=4)

    pack.add_Hex('03')
    data = pack.get_bytes()
    # 头部
    data = Pack_Head_login(info, 'wtlogin.login', data)

    data = Pack_(info, data=data, encryption=2, Types=10, sso_seq=4)
    data = bytes.fromhex(
        ' ')

    return data


def login_res(data, info):
    data = data[15:-1]  # 头部 15字节&去掉尾部03
    _status = data[0]
    data = TEA.decrypt(data[1:], info.share_key)
    if _status == 0:
        data = data[5:]  # 00 09 00 00 02

        pack = pack_u(data)
        _head = pack.get_bin(2).hex()
        _len = pack.get_short()
        data = pack.get_bin(_len)

        if _head == '0119':
            # 判断tlv的头部
            data = TEA.decrypt(data, info.key_tgtgt)
    else:
        data = data[3:]
    un_tlv = Un_Tlv(data, info)

    log.info('登录返回', _status, un_tlv.unpack())


def login_captcha(info, Ticket: str):
    """登录验证码"""
    _tlv = TLV(info)
    pack = pack_b()
    methods = [
        _tlv.T193(Ticket),
        _tlv.T008(),
        _tlv.T104(),
        _tlv.T116(),
        _tlv.T547(),
    ]
    pack.add_Hex('00 02')
    pack.add_int(len(methods), 2)  # 数量

    for method_result in methods:
        pack.add_bin(method_result)
    _data = pack.get_bytes()
    # _data = bytes.fromhex(
    #     '00 02 00 05 01 93 00 8F 74 30 33 53 58 38 37 52 4B 55 51 31 66 61 7A 4A 7A 58 33 56 53 54 5A 54 6E 30 6D 4B 7A 70 6A 4C 71 52 4F 64 61 42 36 31 53 41 45 6E 52 30 43 65 34 52 50 59 6A 34 69 7A 41 68 52 46 78 78 66 6D 67 6D 41 39 59 54 6A 71 58 6D 62 30 6F 52 64 59 47 46 49 6B 43 78 66 32 65 73 33 52 65 6F 4C 34 72 51 75 57 59 71 42 41 4A 70 76 52 68 6D 71 54 41 6B 45 5F 53 53 51 73 73 46 4D 64 44 37 41 31 77 64 43 4B 49 77 71 69 65 46 68 59 37 77 2A 00 08 00 08 00 00 00 00 08 04 00 00 01 04 00 24 41 6C 5A 47 50 32 35 46 73 4B 45 4D 34 59 32 4D 7A 76 6F 34 79 58 7A 70 57 74 6A 43 57 47 32 31 6F 67 3D 3D 01 16 00 0E 00 0A F7 FF 7C 00 01 04 00 01 5F 5E 10 E2 05 47 00 14 01 02 01 01 01 00 00 00 00 02 27 10 00 00 00 21 00 00 27 10')
    data = TEA.encrypt(_data, info.share_key)

    # 头部
    pack = pack_b()
    pack.add_Hex('1F 41')
    pack.add_Hex('08 10')
    pack.add_Hex('00 01')
    pack.add_int(int(info.uin))  # Uin_bytes

    pack.add_Hex('03 07 00 00 00 00 02 00 00 00 00 00 00 00 00')
    pack.add_Hex('02 01')
    pack.add_bin(info.key_rand)  # 不是key
    pack.add_Hex('01 31')
    pack.add_Hex('00 01')

    pack.add_body(info.key_Pubkey, 2)

    pack.add_bin(data)
    data = pack.get_bytes()

    pack.empty()  # 包裹
    pack.add_Hex('02')
    pack.add_body(data, 2, add_len=4)

    pack.add_Hex('03')
    data = pack.get_bytes()
    # 头部
    data = Pack_Head_login(info, 'wtlogin.login', data)

    data = Pack_(info, data=data, encryption=2, Types=10, sso_seq=4)
    return data


def wtlogin_trans(bArr):
    """k值 变体解法"""
    a_sm = b'\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff' \
           b'\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff>\xff\xff?\xff\xff456789:;<=\xff\xff\xff' \
           b'\xff\xff\xff\xff\x00\x01\x02\x03\x04\x05\x06\x07\x08\t\n\x0b\x0c\r\x0e\x0f\x10\x11\x12\x13\x14\x15\x16' \
           b'\x17\x18\x19\xff\xff\xff\xff\xff\xff\x1a\x1b\x1c\x1d\x1e\x1f !"#$%&\'()*+,' \
           b'-./0123\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff' \
           b'\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff' \
           b'\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff' \
           b'\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff' \
           b'\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff' \
           b'\xff\xff\xff\xff\xff'
    if isinstance(bArr, str):
        bArr = bArr.encode()

    i = 32
    i4 = 0
    i3 = 0
    i2 = 0
    b = 0
    bArr2 = bytearray(24)
    while True:
        i6 = i - 1
        if i > 0:
            i7 = i4 + 1
            i5 = bArr[i4]

            if i5 != 0 or i5 == 95:
                if i5 == 32:
                    i5 = 42

                b2 = a_sm[i5]
                if b2 < 0:
                    b = b2
                    i = i6
                    i4 = i7
                else:
                    residue = i3 % 4
                    if residue == 0:
                        bArr2[i2] = b2 << 2
                        i5 = i2
                    elif residue == 1:
                        i5 = i2 + 1

                        bArr2[i2] = bArr2[i2] | (b2 >> 4)
                        bArr2[i5] = (b2 & 0x0F) << 4

                    elif residue == 2:
                        i5 = i2 + 1
                        bArr2[i2] = bArr2[i2] | (b2 >> 2)
                        bArr2[i5] = (b2 & 0x03) << 6
                    elif residue == 3:
                        i5 = i2 + 1
                        bArr2[i2] |= b2
                    else:
                        i5 = i2

                i3 += 1
                i4 = i7
                i = i6
                i2 = i5
                b = b2


        elif b == 95:
            residue = i3 / 4
            if residue == 1:
                break
            elif residue == 2:
                i2 = i2 + 1
        else:
            break

    return bArr2


def trans_emp(info, verify=None):
    if verify:
        # 扫码状态
        pack = pack_b()
        pack.add_Hex('00 00 62 00 00 00 10 00 00 00 72 00 00 00')
        pack.add_int(int(time.time()))
        pack.add_Hex('02 00 5E 00 12 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 03 00 00 00 32 00 '
                     '00 00 01 00 00 00 00 00 00 00 00 00 05 01 00 00 00 73 00 00')
        pack.add_Hex('00 10 ')
        pack.add_int(len(info.UN_Tlv_list.T100_qr_code_mark), 2)
        pack.add_bin(info.UN_Tlv_list.T100_qr_code_mark)
        pack.add_Hex('00 00 00 00 00 00 00 00 08 00 00 00 00 03')

        data = pack.get_bytes()
    else:
        # 获取二维码
        pack = pack_b()
        pack.add_Hex(
            '00 01 0D 00 00 00 10 00 00 00 72 00 00 00 64 C9 FA 20 02 01 09 00 31 00 00 00 00 00 00 00 00 00 00 00 00 '
            '00'
            '00 00 00 00 00 00 00 00 03 00 00 00 32 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 10 00 00 00 00 '
            '00'
            '00 00 00 08 00 00 00 06')
        Tlv = TLV(info)
        pack.add_bin(Tlv.T016())
        pack.add_bin(Tlv.T01B())
        pack.add_bin(Tlv.T01D())
        pack.add_bin(Tlv.T01F())
        pack.add_bin(Tlv.T033())
        pack.add_bin(Tlv.T035())
        pack.add_Hex('03')
        data = pack.get_bytes()
    data = TEA.encrypt(data, info.share_key)
    # 头部
    pack = pack_b()
    pack.add_Hex('1F 41')
    pack.add_Hex('08 12')
    pack.add_Hex('00 01')
    pack.add_Hex('00 00 00 00')  # Uin_bytes
    pack.add_Hex('03 07 00 00 00 00 02 00 00 00 00 00 00 00 00')

    pack.add_Hex('01 01')  # 变化01

    pack.add_bin(info.key_rand)
    pack.add_Hex('01 02')
    pack.add_int(len(info.key_Pubkey), 2)
    pack.add_bin(info.key_Pubkey)
    pack.add_bin(data)
    data = pack.get_bytes()

    pack.empty()  # 包裹
    pack.add_Hex('02')
    pack.add_int(len(data) + 4, 2)  # 短整数
    pack.add_bin(data)
    pack.add_Hex('03')
    data = pack.get_bytes()

    # 头部
    data = Pack_Head_login(info, 'wtlogin.trans_emp', data)
    data = Pack_(info, data=data, encryption=2, Types=10, sso_seq=4)
    return data


def trans_emp_auth(info, **kwargs):
    verify = kwargs.get('verify', False)
    pack = pack_b()
    pack.add_int(int(time.time()))

    if verify:
        pack.add_Hex(
            '02 00 C9 00 14 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 03 00 00 00 32 00 00 00 02 00 00 00 00')
    else:
        pack.add_Hex(
            '02 00 DE 00 13 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 03 00 00 00 32 00 00 00 00 00 00 00 00')

    pack.add_int(int(info.uin))
    pack.add_Hex('00 00 00 00 00 10 00 00 00 00')
    pack.add_int(int(info.uin))
    pack.add_body(wtlogin_trans(kwargs['K']), 2)
    pack.add_body(info.UN_Tlv_list.TGT_T10A, 2)
    if verify:
        pack.add_Hex('08 00 03 00 02 00 08 00 00 00 00 00 00 00 0B 00 15 00 04 00 00 00 00 00 68')
        pack.add_body(info.Guid, 2)
    else:
        pack.add_bin(info.Guid)
        pack.add_Hex('01 00 01 08 00 04 00 03 00 05 00 20 00 36 00 01 00 09')
        pack.add_body('com.tencent.mobileqq', 2)  # 似乎会对其识别
        pack.add_Hex('00 39 00 04 00 00 00 01')

    pack.add_Hex('03')
    data = TEA.encrypt(pack.get_bytes(), info.UN_Tlv_list.userSt_Key)

    pack.empty()
    if verify:
        pack.add_Hex('01 00 D8 00 00 00 10 00 00 00 72 00 60')
    else:
        pack.add_Hex('01 00 F0 00 00 00 10 00 00 00 72 00 60')
    pack.add_bin(info.UN_Tlv_list.userStSig)
    pack.add_Hex('00')
    pack.add_bin(data)

    data = TEA.encrypt(pack.get_bytes(), info.UN_Tlv_list.wtSessionTicketKey)

    pack.empty()
    pack.add_Hex('1F 41')
    pack.add_Hex('08 12')
    pack.add_Hex('00 01')
    pack.add_int(int(info.uin))  # Uin_bytes
    pack.add_Hex('03 45 00 00 00 00 02 00 00 00 00 00 00 00 00 00 30')
    pack.add_bin(info.UN_Tlv_list.wtSessionTicket)
    pack.add_bin(data)

    data = pack.get_bytes()

    pack.empty()  # 包裹
    pack.add_Hex('02')
    pack.add_int(len(data) + 4, 2)  # 短整数
    pack.add_bin(data)
    pack.add_Hex('03')

    data = pack.get_bytes()

    pack.empty()
    pack.add_Hex(
        '00 00 00 27 00 00 00 15 77 74 6C 6F 67 69 6E 2E 74 72 61 6E 73 5F 65 6D 70 00 00 00 08 F7 C0 A1 E8 00 00 00 06 70 00')
    pack.add_int(len(data) + 4, 4)
    pack.add_bin(data)
    data = TEA.encrypt(pack.get_bytes(), '00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00')
    # 头部
    data = Pack_(info, data=data, encryption=2, Types=11, sso_seq=info.seq)
    return data


def trans_emp_auth_res(data, info, **kwargs):
    auth_info = {}
    verify = kwargs.get('verify', False)
    auth_info['verify'] = verify
    data = TEA.decrypt(data[16:-1], info.UN_Tlv_list.wtSessionTicketKey)
    data = TEA.decrypt(data[5:], info.UN_Tlv_list.userSt_Key)
    data = data[53:]
    pack = pack_u(data)
    status = pack.get_byte()

    if status != 0:
        _len = pack.get_short()
        message = pack.get_bin(_len).decode('utf-8')
        auth_info['message'] = message
    else:
        _time = pack.get_int(4)
        _len = pack.get_short()
        AuthName = pack.get_bin(_len).decode('utf-8')
        auth_info['AuthName'] = AuthName
        if verify:
            # 确认授权
            pack.get_short()
        data = pack.get_all()
        TLv = Un_Tlv(data, info)
        TLv.unpack()

        auth_info.update(TLv.get_auth_result())
    auth_info['status'] = status
    return auth_info


def trans_emp_res(data, info, verify):
    status_message = {
        48: '请使用手机QQ扫描二维码登录',
        53: '扫描成功,请在手机上确认登录',
        54: '用户已取消登录',
        99: '请扫描二维码',
        0: '完成授权'
    }
    pack = pack_u(data)
    pack.get_byte()  # 02
    pack.get_int(2)  # len

    pack = pack_u(pack.get_all())
    pack.get_bin(10)  # 1f 41 08 12 00 01 00 00 00 00
    pack.get_int(2)  # ?
    pack.get_byte()  # ?
    data = pack.get_all()

    data = TEA.decrypt(data[:-1], info.share_key)
    if verify:
        status = data[-2]
        qrCode = None
        if status == 0:
            data = data[72:]
            Un_Tlv(data, info).unpack()

            log.info('扫码完成', data.hex())


    else:
        status = 99

        data = data[53:]  # 去掉前面
        pack = pack_u(data)
        pack.get_bin(2)  # tlv
        _len = pack.get_int(2)  # len
        info.UN_Tlv_list.T100_qr_code_mark = pack.get_bin(_len)  # data
        pack.get_bin(2)  # tlv
        pack.get_int(2)  # len
        _len = pack.get_int(2)
        qrCode = pack.get_bin(_len)  # data
    message = status_message.get(status, "未知状态")
    return qrCode, status, message


def wtlogin_exchange_emp(info):
    """"
    更新令牌,todo 需要修改公钥和私钥
    :param info:
    """

    info.key_Pubkey = bytes.fromhex(
        '04 70 83 E0 93 38 B0 49 98 89 88 B7 8B 87 D8 B0 03 CE 45 B2 6D A6 92 21 84 67 A0 63 49 6F 78 B3 36 06 36 E2 19 8D 18 85 57 DA 0D 30 2D 2E 53 1E 2C C2 2C 21 4B 92 7F 8A 5B BC CC AD 33 19 AF F3 1A')
    _tlv = TLV(info)

    methods = [
        _tlv.T100(5, 16, 0, 34869472),
        _tlv.T10A(info.UN_Tlv_list.TGT_T10A),

        _tlv.T116(2),
        _tlv.T143(info.UN_Tlv_list.D2_T143),

        _tlv.T142(),
        _tlv.T154(),

        _tlv.T017(info.device.app_id, int(info.uin), info.login_time),
        _tlv.T141(),

        _tlv.T008(),

        _tlv.T147(),

        _tlv.T177(),
        _tlv.T187(),
        _tlv.T188(),
        _tlv.T202(),
        _tlv.T511()
    ]

    pack = pack_b()
    pack.add_Hex('00 0B')
    pack.add_int(len(methods), 2)  # 数量
    for method_result in methods:
        pack.add_bin(method_result)

    Buffer_tlv = pack.get_bytes()

    Buffer_tlv = TEA.encrypt(Buffer_tlv, bytes.fromhex('48 23 99 47 A6 E9 76 DF A5 43 26 F1 FB DE 51 18'))

    pack.empty()
    pack.add_Hex('1F 41')
    pack.add_Hex('08 10')
    pack.add_Hex('00 01')
    pack.add_int(int(info.uin))
    pack.add_Hex('03 07 00 00 00 00 02 00 00 00 00 00 00 00 00')
    pack.add_Hex('02 01')

    pack.add_bin(info.key_rand)
    pack.add_Hex('01 31')
    pack.add_Hex('00 01')
    pack.add_body(info.key_Pubkey, 2)
    pack.add_bin(Buffer_tlv)
    Buffer = pack.get_bytes()

    pack.empty()
    pack.add_Hex('02')
    pack.add_body(Buffer, 2, add_len=4)
    pack.add_Hex('03')
    Buffer = pack.get_bytes()
    pack.empty()
    Buffer = Pack_Head_login(info, 'wtlogin.exchange_emp', Buffer)
    Buffer = Pack_(info, data=Buffer, encryption=2, Types=10, sso_seq=4)
    return Buffer


def wtlogin_exchange_emp_rsp(info, Buffer: bytes):
    # 其实和登录返回没区别
    Buffer = Buffer[15:-1]  # 头部 15字节&去掉尾部03
    _status = Buffer[0]

    Buffer = TEA.decrypt(Buffer[1:], bytes.fromhex('48 23 99 47 A6 E9 76 DF A5 43 26 F1 FB DE 51 18'))
    if _status == 0:
        Buffer = Buffer[5:]  # 00 09 00 00 02

        pack = pack_u(Buffer)
        _head = pack.get_bin(2).hex()
        _len = pack.get_short()
        Buffer = pack.get_bin(_len)

        if _head == '0119':
            # 判断tlv的头部
            Buffer = TEA.decrypt(Buffer, get_md5(info.share_key))

    else:
        Buffer = Buffer[3:]
    un_tlv = Un_Tlv(Buffer, info)
    un_tlv.unpack()
    if _status == 0:
        info.emp_time = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        return {'status': _status, 'cookie': info.cookies}

    return {'status': _status, 'message': '缓存更新异常'}


if __name__ == '__main__':
    pass
    # print(bytes.fromhex('00 01'))
    # a = b'\0x\17c'.hex()
    # print(a)



# package cooperation.qzone;
import time
import zlib
from typing import Union

from Jce_b import JceWriter, JceReader, IJceStruct

from AndroidQQ.struct.QMF_PROTOCAL import QmfUpstream, QmfTokenInfo, QmfClientIpInfo, QmfBusiControl, RetryInfo, \
    QmfDownstream


def createBusiControl(compFlag, length, SUPPORT_COMPRESS):
    Qmf_Busi_Control = QmfBusiControl(
        compFlag=compFlag,
        lenBeforeComp=length,  # 补偿前的长度
        rspCompFlag=SUPPORT_COMPRESS
    ).to_bytes()
    _Buffer = JceWriter().write_jce_struct(Qmf_Busi_Control, 0)

    _Buffer = JceWriter().write_map({'busiCompCtl': {
        'QMF_PROTOCAL.QmfBusiControl': _Buffer
    }}, 0)
    return _Buffer


def createQmfUpstream(info, compFlag: int, BusiBuff: bytes, ServiceCmd: str):
    """"
            创建 Qmf
                compFlag: 比较标志  1 =压缩
                BusiBuff: 业务数据
    """

    Extra = createBusiControl(
        compFlag=compFlag,
        length=len(BusiBuff),  # 压缩前的长度
        SUPPORT_COMPRESS=1

    )

    TokenInfo = QmfTokenInfo(
        Type=64,
        Key=b'',
        ext_key={1: bytearray.fromhex('00')}
    )

    ClientIpInfo = QmfClientIpInfo(
        IpType=0,
        ClientPort=0,
        ClientIpv4=0,
        ClientIpv6=bytearray.fromhex('00 00 00 00 00 00')
    )

    _RetryInfo = RetryInfo(
        Flag=1,
        RetryCount=0,
        PkgId=int(time.time() * 1000)

    )
    if compFlag:
        BusiBuff = zlib.compress(BusiBuff)
    Upstream = QmfUpstream(
        Seq=info.seq,
        Appid=1000027,
        Uin=int(info.uin),
        Qua='V1_AND_SQ_8.9.83_4680_YYB_D',
        ServiceCmd=ServiceCmd,
        # DeviceInfo='i=8e47e13209285931450588fb100013d16b0b&imsi=8e47e13209285931450588fb100013d16b0b&mac=02:00:00:00:00:00&m=V1916A&o=9&a=28&sd=0&c64=1&sc=1&p=540*960&aid=8e47e13209285931450588fb100013d16b0b&f=vivo&mm=3946&cf=2798&cc=4&qimei=8e47e13209285931450588fb100013d16b0b&qimei36=8e47e13209285931450588fb100013d16b0b&sharpP=1&n=wifi&support_xsj_live=true&client_mod=default&qadid=&md5_android_id=&md5_mac=&client_ipv4=&aid_ticket=&taid_ticket=0101869FEA6C27834C685B0CF0ED44C4516C368A5F048AE3AA301973FA34D55425FBFF12CA010BAB2CE55BFB&muid=&muid_type=0&device_ext=%7B%22attri_info%22%3A%7B%22ua%22%3A%22Dalvik%5C%2F2.1.0+%28Linux%3B+U%3B+Android+9%3B+V1916A+Build%5C%2FPQ3B.190801.002%29%22%2C%22ua_i%22%3A%7B%22c_i%22%3A%2291.0.4472.114%22%2C%22s_i%22%3A%7B%22b_i%22%3A%22PQ3B.190801.002%22%2C%22b_m%22%3A%22V1916A%22%2C%22b_mf%22%3A%22vivo%22%2C%22b_r_o_c%22%3A%229%22%2C%22b_v_c%22%3A%22REL%22%2C%22b_v_i%22%3A%22G9650ZHU2ARC6%22%2C%22b_v_r%22%3A%229%22%2C%22jvm_v%22%3A%222.1.0%22%2C%22sw_s%22%3A%221%22%7D%7D%7D%2C%22font_size%22%3A1%2C%22harmony_sys_info%22%3A%7B%22harmony_pure_mode%22%3A-1%2C%22is_harmony_os%22%3Afalse%7D%2C%22hevc_compatibility_info%22%3A%5B%7B%22max_fps%22%3A30%2C%22max_luma_samples%22%3A%22921600%22%2C%22video_player_type%22%3A1%7D%5D%2C%22jump_ability%22%3A%5B9999%5D%2C%22module_name%22%3A%22pcad-reward%22%2C%22mqq_config_status%22%3A1%2C%22qi36%22%3A%228e47e13209285931450588fb100013d16b0b%22%2C%22qqb_external_exp_info%22%3A%7B%22exp_id%22%3A%5B%22gdt_tangram_qq_android_000006%22%2C%22gdt_tangram_qq_android_000010%22%5D%2C%22traffic_type%22%3A26%7D%2C%22targeting_ability%22%3A%7B%22support_quick_app_link%22%3Afalse%2C%22web_wx_mgame%22%3Atrue%7D%2C%22wechat_installed_info%22%3A%7B%22api_ver%22%3A%220%22%7D%7D&video_auto_play=1&sound_auto_play=0&qimei=8e47e13209285931450588fb100013d16b0b&longitude=&latitude=&coordtype=0&timezone=+8,id:Asia/Shanghai&is_teenager_mod=0&is_care_mod=0&feeds_new_style=1&feed_in_tab=0&AV1=1&hwlevel=1',
        DeviceInfo='',
        Token=TokenInfo,
        IpInfo=ClientIpInfo,
        BusiBuff=BusiBuff,
        Extra=Extra,
        flag=0,
        sessionID=0,
        retryinfo=_RetryInfo,

    ).to_bytes()

    return Upstream


def UnQmfDownstream(Buffer: bytes, key_1: str, key_2: str):
    """解QMF"""

    stream = QmfDownstream()
    stream.read_from(JceReader(Buffer))

    Buffer_head = stream.BusiBuff[:1]
    if Buffer_head == bytearray(b'x'):
        BusiBuff = zlib.decompress(stream.BusiBuff)
    else:
        BusiBuff = stream.BusiBuff

    BusiBuff = JceReader(BusiBuff).read_map(0)

    rsp_Buffer = BusiBuff.get(key_1, {}).get(key_2, b'')
    msg_Buffer = BusiBuff.get('msg', {}).get('string', b'')
    ret_Buffer = BusiBuff.get('ret', {}).get('int32', b'')
    msg = JceReader(msg_Buffer).read_string(0)
    ret = JceReader(ret_Buffer).read_int64(0)

    return rsp_Buffer, msg, ret



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cmd0xeb8.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63md0xeb8.proto\x12\x18tencent.im.oidb.cmd0xeb8\"m\n\tPhoneInfo\x12\x12\n\nphone_type\x18\x01 \x01(\r\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\r\n\x05phone\x18\x03 \x01(\t\x12\x14\n\x0cphone_status\x18\x04 \x01(\r\x12\x11\n\tvas_phone\x18\x05 \x01(\x0c\")\n\x07ReqBody\x12\x0b\n\x03src\x18\x01 \x01(\r\x12\x11\n\tproto_ver\x18\x02 \x01(\r\"\xfd\x01\n\x07RspBody\x12\x14\n\x0c\x63heck_result\x18\x01 \x01(\r\x12\x37\n\nphone_info\x18\x02 \x03(\x0b\x32#.tencent.im.oidb.cmd0xeb8.PhoneInfo\x12\x15\n\rmibao_set_url\x18\x03 \x01(\t\x12\x18\n\x10mibao_change_url\x18\x04 \x01(\t\x12\x18\n\x10mibao_verify_url\x18\x05 \x01(\t\x12\x1b\n\x13verify_premibao_url\x18\x06 \x01(\t\x12\x15\n\rhori_bar_tips\x18\x07 \x01(\t\x12\x14\n\x0cred_dot_tips\x18\x08 \x01(\t\x12\x0e\n\x06is_IOT\x18\t \x01(\x08')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cmd0xeb8_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PHONEINFO']._serialized_start=44
  _globals['_PHONEINFO']._serialized_end=153
  _globals['_REQBODY']._serialized_start=155
  _globals['_REQBODY']._serialized_end=196
  _globals['_RSPBODY']._serialized_start=199
  _globals['_RSPBODY']._serialized_end=452
# @@protoc_insertion_point(module_scope)



from typing import Union

from Jce_b import IJceStruct, JceWriter
from Jce_b.typing import JceReader


class mobile_applist_req(IJceStruct):
    album_show_type: int = 0
    appid: int = 0
    attach_info: str = ""
    count: int = 10
    extrance_type: int = 0
    mapEx: dict = None
    refresh_type: int = 0
    uin: int = 0

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        Jce = JceWriter()
        Jce.write_object(self.uin, 0)
        Jce.write_object(self.appid, 1)
        Jce.write_object(self.count, 2)
        if self.attach_info is not None:
            Jce.write_object(self.attach_info, 3)

        Jce.write_object(self.album_show_type, 4)
        Jce.write_object(self.refresh_type, 5)

        Jce.write_object(self.extrance_type, 6)
        Jce.write_object(self.mapEx, 7)
        return Jce.bytes()



import json
# 对象数据服务
from google.protobuf.json_format import MessageToJson, MessageToDict

from AndroidQQ.proto import *
from AndroidQQ.struct.head import *
from pyproto import ProtoBuf


def P0xccd(info, **kwargs):
    """删除授权信息"""
    _dict = {1: 3277, 2: 1, 3: 0, 4: {2: kwargs.get('appid', 0), 3: 1}}
    _data = ProtoBuf(_dict).toBuf()
    _data = PackHeadNoToken(info, _data, 'OidbSvc.0xccd')
    _data = Pack_(info, _data, Types=11, encryption=1, sso_seq=info.seq)
    return _data


def P0xccd_res(data):
    _dict = ProtoBuf(data).toDictAuto()
    return _dict



# package NS_MOBILE_FEEDS;

from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader


class cell_comm(IJceStruct):
    # 通讯
    actiontype: int = 0
    actionurl: str = ""
    adv_stytle: int = 0
    adv_subtype: int = 0
    appid: int = 0
    clientkey: str = ""
    curlikekey: str = ""
    # custom_droplist: Optional[List[S_droplist_option]] = None
    editmask: int = 4294967295
    # extendInfo: Optional[Dict[str, str]] = None
    # extendInfoData: Optional[Dict[str, bytes]] = None
    feedsDelTime: int = 0
    feedsattr: int = 0
    feedsattr2: int = 0
    feedsattr3: int = 0
    feedsid: str = ""
    feedskey: str = ""
    feedstype: int = 0
    hot_score: int = 0
    iClick_area: int = 0
    interestkey: str = ""
    is_kuolie: bool = False
    is_stay: bool = False
    operatemask: int = 0
    operatemask2: int = 0
    operatemask3: int = 0
    orglikekey: str = ""
    originaltype: int = 0
    paykey: str = ""
    positionmask: int = 0
    positionmask2: int = 0
    pull_qzone: bool = False
    recom_show_type: int = 0
    recomlayout: int = 0
    recomreportid: int = 0
    recomtype: int = 0
    refer: str = ""
    reportfeedsattr: int = 0
    right_info: dict = None  # UgcRightInfo 不解析
    shield: int = 0
    show_mask: int = 0
    space_right: int = 0
    sqDynamicFeedsKey: str = ""
    # stMapABTest: Optional[Dict[int, int]] = None
    subid: int = 0
    time: int = 0
    uflag: int = 0
    ugckey: str = ""
    ugcrightkey: str = ""
    wup_feeds_type: int = 0

    def read_from(self, reader: JceReader) -> None:
        self.appid = reader.read_any(0)
        self.subid = reader.read_any(1)
        self.refer = reader.read_any(2)
        self.time = reader.read_any(3)
        self.actiontype = reader.read_any(4)
        self.actionurl = reader.read_any(5)
        self.originaltype = reader.read_any(6)
        self.operatemask = reader.read_any(7)
        self.feedskey = reader.read_any(8)
        self.orglikekey = reader.read_any(9)
        self.curlikekey = reader.read_any(10)
        self.feedstype = reader.read_any(11)
        self.feedsattr = reader.read_any(12)
        self.ugckey = reader.read_any(13)
        self.clientkey = reader.read_any(14)
        self.show_mask = reader.read_any(15)
        self.uflag = reader.read_any(16)
        self.shield = reader.read_any(17)
        self.ugcrightkey = reader.read_any(18)
        self.interestkey = reader.read_any(19)
        self.recomtype = reader.read_any(20)
        self.feedsid = reader.read_any(21)
        self.adv_stytle = reader.read_any(22)
        self.adv_subtype = reader.read_any(23)
        self.right_info = reader.read_any_with_tag(24)
        self.recomlayout = reader.read_any(25)
        self.recomreportid = reader.read_any(26)
        self.space_right = reader.read_any(27)
        self.reportfeedsattr = reader.read_any(28)
        self.recom_show_type = reader.read_any(29)
        self.wup_feeds_type = reader.read_any(30)

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass



# package QMF_PROTOCAL;
from .QmfClientIpInfo import *

from .QmfTokenInfo import *
from .RetryInfo import *


class QmfUpstream(IJceStruct):
    Appid: int
    BusiBuff: bytes
    DeviceInfo: str
    Extra: bytes
    IpInfo: QmfClientIpInfo
    Qua: str
    Seq: int
    ServiceCmd: str
    Token: QmfTokenInfo
    Uin: int
    flag: int
    retryinfo: RetryInfo
    sessionID: int

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        Jce = JceWriter()
        Jce.write_object(self.Seq, 0)
        Jce.write_object(self.Appid, 1)
        Jce.write_object(self.Uin, 2)
        Jce.write_object(self.Qua, 3)
        Jce.write_object(self.ServiceCmd, 4)
        Jce.write_object(self.DeviceInfo, 5)
        Jce.write_jce_struct(self.Token.to_bytes(), 6)
        Jce.write_jce_struct(self.IpInfo.to_bytes(), 7)
        Jce.write_object(self.BusiBuff, 8)
        Jce.write_object(self.Extra, 9)
        Jce.write_object(self.flag, 10)
        Jce.write_object(self.sessionID, 11)
        if self.retryinfo is not None:
            Jce.write_jce_struct(self.retryinfo.to_bytes(), 12)
        return Jce.bytes()



from google.protobuf.json_format import MessageToDict

from AndroidQQ.im.oidb.oidb_0xc05 import *
from AndroidQQ.im.oidb.oidb_sso import OIDBSSOPkg
from AndroidQQ.struct import PackHeadNoToken, Pack_


def OidbSvc_0xc05(info, start: int, limit: int):
    getAuthAppListinfoReq = GetAuthAppListReq(
        start=start,
        limit=limit
    )
    req_body = ReqBody(
        get_auth_app_list_req=getAuthAppListinfoReq
    )
    oIDBSSOPkg = OIDBSSOPkg(
        command=3077,
        result=0,
        service_type=1,
        bodybuffer=req_body.SerializeToString(),
    )
    buffer = oIDBSSOPkg.SerializeToString()
    buffer = PackHeadNoToken(info, buffer, 'OidbSvc.0xc05')
    buffer = Pack_(info, buffer, Types=11, encryption=1, sso_seq=info.seq)
    return buffer


def OidbSvc_0xc05_rep(buffer):
    oIDBSSOPkg = OIDBSSOPkg()
    oIDBSSOPkg.ParseFromString(buffer)
    rep_body = RspBody()
    rep_body.ParseFromString(oIDBSSOPkg.bodybuffer)
    return MessageToDict(rep_body)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oidb_sso.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eoidb_sso.proto\x12\x18tencent.im.oidb.oidb_sso\"&\n\x08MetaData\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xbf\x01\n\nOIDBSSOPkg\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\r\x12\x14\n\x0cservice_type\x18\x02 \x01(\r\x12\x0e\n\x06result\x18\x03 \x01(\r\x12\x12\n\nbodybuffer\x18\x04 \x01(\x0c\x12\x11\n\terror_msg\x18\x05 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x06 \x01(\t\x12;\n\x0ftrpc_trans_info\x18\x07 \x03(\x0b\x32\".tencent.im.oidb.oidb_sso.MetaData')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oidb_sso_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_METADATA']._serialized_start=44
  _globals['_METADATA']._serialized_end=82
  _globals['_OIDBSSOPKG']._serialized_start=85
  _globals['_OIDBSSOPKG']._serialized_end=276
# @@protoc_insertion_point(module_scope)



from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader
from .cmshow_active_result import cmshow_active_result


class operation_like_rsp(IJceStruct):
    ret: int = 0
    msg: str = ''
    cmshow_active_result: IJceStruct = None  # 厘米秀

    def read_from(self, reader: JceReader) -> None:
        self.ret = reader.read_any(0)
        self.msg = reader.read_any(1)
        self.cmshow_active_result = reader.read_object(cmshow_active_result)  # 厘米秀
    def to_bytes(self) -> Union[bytes, bytearray]:
        pass



from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader

from AndroidQQ.struct.NS_MOBILE_FEEDS.s_outshare import s_outshare


class cell_operation(IJceStruct):
    busi_param: dict = None
    button_gif_url: str = ""
    bypass_param: dict = None
    click_stream_report: dict = None
    custom_btn: list = None
    droplist_cookie: dict = None
    feed_report_cookie: dict = None
    generic_url: str = ""
    offline_resource_bid: int = 0
    qboss_trace: str = ""
    qq_url: str = ""
    rank_param: dict = None
    recomm_cookie: dict = None
    schema_info: dict = None
    share_info: IJceStruct = None
    weixin_url: str = ""

    def read_from(self, reader: JceReader) -> None:
        self.busi_param = reader.read_any(0)
        self.weixin_url = reader.read_any(1)
        self.qq_url = reader.read_any(2)
        self.share_info = reader.read_object(s_outshare)
        self.schema_info = reader.read_any(4)
        self.recomm_cookie = reader.read_any(5)
        self.click_stream_report = reader.read_any(6)
        self.qboss_trace = reader.read_any(7)
        self.custom_btn = reader.read_any(8)
        self.feed_report_cookie = reader.read_map(9)
        self.generic_url = reader.read_any(10)
        self.bypass_param = reader.read_any(11)
        self.droplist_cookie = reader.read_any(12)
        self.rank_param = reader.read_any(13)
        self.button_gif_url = reader.read_any(14)
        self.offline_resource_bid = reader.read_any(15)

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: wtlogin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rwtlogin.proto\"\xc3\x01\n\x0c\x44\x65viceReport\x12\x12\n\nbootloader\x18\x01 \x01(\t\x12\x14\n\x0cproc_version\x18\x02 \x01(\t\x12\x10\n\x08\x63odename\x18\x03 \x01(\t\x12\x13\n\x0bincremental\x18\x04 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x05 \x01(\t\x12\x0f\n\x07\x62oot_id\x18\x06 \x01(\t\x12\x12\n\nandroid_id\x18\x07 \x01(\t\x12\x11\n\tbase_band\x18\x08 \x01(\t\x12\x15\n\rinner_version\x18\t \x01(\t')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'wtlogin_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DEVICEREPORT']._serialized_start=18
  _globals['_DEVICEREPORT']._serialized_end=213
# @@protoc_insertion_point(module_scope)



from Jce_b import JceWriter

from AndroidQQ.struct import PackHead_QMF
from AndroidQQ.struct.NS_MOBILE_OPERATION import operation_delugc_req
from AndroidQQ.struct.cooperation import createQmfUpstream, UnQmfDownstream


def SQQzoneSvc_delUgc(info, srcId):
    """
        删除说说
    """
    mapEx = {
        'del_all_media_file': '0'
    }

    int64 = JceWriter().write_int64(int(info.uin), 0).bytes()
    delugc_req = operation_delugc_req(
        appid=311,
        uin=int(info.uin),
        ownuin=int(info.uin),
        srcId=srcId,
        mapEx=mapEx,
    ).to_bytes()
    Buffer = JceWriter().write_jce_struct(delugc_req, 0)

    Buffer = JceWriter().write_map({'delUgc': {
        'NS_MOBILE_OPERATION.operation_delugc_req': Buffer
    }, 'hostuin': {'int64': int64}}, 0)

    Upstream = createQmfUpstream(info, 1, Buffer, 'QzoneNewService.delUgc')
    Buffer = PackHead_QMF(info, 'SQQzoneSvc.delUgc', Upstream)
    return Buffer


def SQQzoneSvc_delUgc_rsp(buffer):
    rsp_Buffer, msg, ret = UnQmfDownstream(buffer, 'delUgc', 'NS_MOBILE_OPERATION.operation_delugc_rsp')
    return {'msg': msg, 'ret': ret}



from Jce_b import JceWriter, JceReader

from AndroidQQ.struct.cooperation import createQmfUpstream, UnQmfDownstream
from AndroidQQ.struct import PackHead_QMF
from AndroidQQ.struct.NS_MOBILE_OPERATION import operation_like_req, operation_like_rsp


def SQQzoneSvc_like(info, target_Uin: int, title: str, feedskey: str):
    def _operation_like_req():
        int64 = JceWriter().write_int64(int(info.uin), 0).bytes()
        curkey = f'http://user.qzone.qq.com/{target_Uin}/mood/{feedskey}'

        busi_param = {
            # 最终生成的会和腾讯有所不同,但似乎没有影响
            97: f'&feedtype1=1&feedtype2=3&feedtype3=1&org_uniq_key=&sUniqId={target_Uin}_311_{feedskey}&fExposUniqId=&colorexptid=0&colorstrategyid=0',
            156: f'appid:311 typeid:0 feedtype:2 hostuin:{info.uin} feedskey:{feedskey} ',
            4: '',
            5: curkey,
            101: f'0=&1=&2=&3=&4={target_Uin}&5=&6=0&7=&8=&9=&10=0&76=',
            6: curkey,
            104: '',
            141: '',
            142: '5',
            207: '0',
            48: '0',
            52: '',
            23: '0',
            184: title,
            121: f'&feedtype1=1&feedtype2=3&feedtype3=1&org_uniq_key=&sUniqId={target_Uin}_311_{feedskey}&fExposUniqId=&colorexptid=0&colorstrategyid=0'}

        OperationLikeReq = operation_like_req(uin=int(info.uin),
                                              curkey=curkey,
                                              unikey=curkey,
                                              action=0,
                                              appid=311,
                                              busi_param=busi_param,
                                              hostuin=0
                                              ).to_bytes()

        OperationLikeReq = JceWriter().write_jce_struct(OperationLikeReq, 0)
        _Buffer = JceWriter().write_map({'like': {
            'NS_MOBILE_OPERATION.operation_like_req': OperationLikeReq
        }, 'hostuin': {'int64': int64}}, 0)
        return _Buffer

    BusiBuff = _operation_like_req()
    Upstream = createQmfUpstream(info, 1, BusiBuff, 'QzoneNewService.like')
    Buffer = PackHead_QMF(info, 'SQQzoneSvc.like', Upstream)
    return Buffer




def SQQzoneSvc_like_rsp(Buffer: bytes):
    rsp_Buffer, msg, ret = UnQmfDownstream(Buffer, 'like', 'NS_MOBILE_OPERATION.operation_like_rsp')
    if rsp_Buffer == b'':
        return {'Busi': {}, 'msg': msg, 'ret': ret}
    like_rsp = JceReader(rsp_Buffer).read_object(operation_like_rsp)
    return {'Busi': like_rsp.to_dict(), 'msg': msg, 'ret': ret}


if __name__ == '__main__':
    pass



import random


def random_mac():
    return "02:%02x:%02x:%02x:%02x:%02x" % (
        random.randint(0, 255),
        random.randint(0, 255),
        random.randint(0, 255),
        random.randint(0, 255),
        random.randint(0, 255)
    )


def random_imei():
    first14 = ''.join(str(random.randint(0, 9)) for i in range(14))
    return first14 + str((10 - sum((3, 1)[i % 2] * int(x) for i, x in enumerate(reversed(first14))) % 10) % 10)


if __name__ == "__main__":
    print(random_mac(), random_imei())

    pass



from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader


class cell_userinfo(IJceStruct):
    # 用户信息
    action_desc: str = ""
    actiontype: int = 5
    luckyMoneyPics: list[str] = []
    user:dict = None  # 不解析

    def read_from(self, reader: JceReader) -> None:
        self.user = reader.read_any(0)
        self.action_desc = reader.read_string(1)
        self.actiontype = reader.read_int32(2)
        self.luckyMoneyPics = reader.read_any(3)

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass



# package com.qzone.proxy.feedcomponent.model;
import json

from Jce import JceInputStream, JceStruct
from Jce_b import JceReader

from AndroidQQ.struct.NS_MOBILE_FEEDS.cell_comm import cell_comm
from AndroidQQ.struct.NS_MOBILE_FEEDS.cell_operation import cell_operation
from AndroidQQ.struct.NS_MOBILE_FEEDS.cell_userinfo import cell_userinfo


# def JceCellData(singlefeed: tuple):
#     buffer = singlefeed[1]
#     if singlefeed[0] == 0:
#         cell = cell_comm()  # 添加实例属性
#         cell.read_from(JceReader(buffer))
#     elif singlefeed[0] == 1:
#         cell = cell_userinfo()
#         cell.read_from(JceReader(buffer))
#
#     else:
#         # 自动解析
#         stream = JceInputStream(buffer)
#         jce_wup = JceStruct()
#         jce_wup.read_from(stream)
#         cell = json.loads(jce_wup.to_json())
#     return cell

class JceCellData:

    def __init__(self, singlefeed: dict):

        buffer = singlefeed.get(0, None)
        if buffer is not None:
            self.cell_comm = cell_comm()  # 添加实例属性
            self.cell_comm.read_from(JceReader(buffer))

        buffer = singlefeed.get(1, None)
        if buffer is not None:
            self.cell_userinfo = cell_userinfo()
            self.cell_userinfo.read_from(JceReader(buffer))

        buffer = singlefeed.get(18, None)
        if buffer is not None:
            self.cell_operation = cell_operation()
            self.cell_operation.read_from(JceReader(buffer))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AndroidQQ/im/oidb/oidb_0xc05/oidb_0xc05.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from AndroidQQ.im.oidb.qqconnect import qqconnect_pb2 as AndroidQQ_dot_im_dot_oidb_dot_qqconnect_dot_qqconnect__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-AndroidQQ/im/oidb/oidb_0xc05/oidb_0xc05.proto\x12\x0ftencent.im.oidb\x1a+AndroidQQ/im/oidb/qqconnect/qqconnect.proto\"1\n\x11GetAuthAppListReq\x12\r\n\x05start\x18\x01 \x01(\r\x12\r\n\x05limit\x18\x02 \x01(\r\"g\n\x11GetAuthAppListRsp\x12\x13\n\x0btotal_count\x18\x01 \x01(\r\x12*\n\x08\x61ppinfos\x18\x02 \x03(\x0b\x32\x18.tencent.im.oidb.Appinfo\x12\x11\n\tcur_index\x18\x03 \x01(\r\"3\n\x13GetCreateAppListReq\x12\r\n\x05start\x18\x01 \x01(\r\x12\r\n\x05limit\x18\x02 \x01(\r\"*\n\x13GetCreateAppListRsp\x12\x13\n\x0btotal_count\x18\x01 \x01(\r\"\x93\x01\n\x07ReqBody\x12\x45\n\x17get_create_app_list_req\x18\n \x01(\x0b\x32$.tencent.im.oidb.GetCreateAppListReq\x12\x41\n\x15get_auth_app_list_req\x18\x0b \x01(\x0b\x32\".tencent.im.oidb.GetAuthAppListReq\"\xa4\x01\n\x07RspBody\x12\x0f\n\x07wording\x18\x01 \x01(\t\x12\x45\n\x17get_create_app_list_rsp\x18\n \x01(\x0b\x32$.tencent.im.oidb.GetCreateAppListRsp\x12\x41\n\x15get_auth_app_list_rsp\x18\x0b \x01(\x0b\x32\".tencent.im.oidb.GetAuthAppListRsp')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AndroidQQ.im.oidb.oidb_0xc05.oidb_0xc05_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETAUTHAPPLISTREQ']._serialized_start=111
  _globals['_GETAUTHAPPLISTREQ']._serialized_end=160
  _globals['_GETAUTHAPPLISTRSP']._serialized_start=162
  _globals['_GETAUTHAPPLISTRSP']._serialized_end=265
  _globals['_GETCREATEAPPLISTREQ']._serialized_start=267
  _globals['_GETCREATEAPPLISTREQ']._serialized_end=318
  _globals['_GETCREATEAPPLISTRSP']._serialized_start=320
  _globals['_GETCREATEAPPLISTRSP']._serialized_end=362
  _globals['_REQBODY']._serialized_start=365
  _globals['_REQBODY']._serialized_end=512
  _globals['_RSPBODY']._serialized_start=515
  _globals['_RSPBODY']._serialized_end=679
# @@protoc_insertion_point(module_scope)



from Jce_b import JceWriter
from pydantic import BaseModel


class DestQQHeadInfo(BaseModel):
    dstUin: int = 0
    dwTimestamp: int = 0
    phoneNum: str = None

    def writeTo(self):
        """目标用户信息"""
        jce = JceWriter()
        jce.write_int64(self.dstUin, 0)
        jce.write_int64(self.dwTimestamp, 1)
        if self.phoneNum is not None:
            jce.write_string(self.phoneNum, 2)
        return jce.bytes()



from pyproto import ProtoBuf

from AndroidQQ.struct import PackHeadNoToken, Pack_


def OidbSvcTrpcTcp_0xfe1_2(info):
    """查询非好友"""
    buffer = ProtoBuf({1: 4065, 2: 2, 4: {1: 'u_YzatHGDbllkvQ41liEoiyQ', 3: {1: 20037}}, 5: ''}
                      ).toBuf()
    buffer = PackHeadNoToken(info, buffer, 'OidbSvcTrpcTcp.0xfe1_2')
    buffer = Pack_(info, buffer, Types=11, encryption=1, sso_seq=info.seq)
    return buffer



import gzip
import hashlib
import json
import random
import re
import time
from io import BytesIO
from urllib.parse import urlparse, parse_qs

import requests

from AndroidQQ.http import User_Agent
from AndroidQQ.utils import qq_bkn


def music_sign(data):
    k1 = {
        '0': 0, '1': 1, '2': 2, '3': 3, '4': 4, '5': 5, '6': 6, '7': 7, '8': 8, '9': 9,
        'A': 10, 'B': 11, 'C': 12, 'D': 13, 'E': 14, 'F': 15,
    }
    l1 = [212, 45, 80, 68, 195, 163, 163, 203, 157, 220, 254, 91, 204, 79, 104, 6]
    t = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="
    md5_bytes = hashlib.md5(data.encode()).hexdigest().upper()
    t1 = md5_bytes[21] + md5_bytes[4] + md5_bytes[9] + md5_bytes[26] + md5_bytes[16] + md5_bytes[20] + md5_bytes[27] + \
         md5_bytes[30]
    t3 = md5_bytes[18] + md5_bytes[11] + md5_bytes[3] + md5_bytes[2] + md5_bytes[1] + md5_bytes[7] + md5_bytes[6] + \
         md5_bytes[25]
    ls2 = []
    for i in range(16):
        x1 = k1[md5_bytes[i * 2]]
        x2 = k1[md5_bytes[i * 2 + 1]]
        x3 = ((x1 * 16) ^ x2) ^ l1[i]
        ls2.append(x3)
    ls3 = []
    for i in range(6):
        if i == 5:
            ls3.append(t[ls2[len(ls2) - 1] >> 2])
            ls3.append(t[(ls2[len(ls2) - 1] & 3) << 4])
        else:
            x4 = ls2[i * 3] >> 2
            x5 = (ls2[i * 3 + 1] >> 4) ^ ((ls2[i * 3] & 3) << 4)
            x6 = (ls2[i * 3 + 2] >> 6) ^ ((ls2[i * 3 + 1] & 15) << 2)
            x7 = 63 & ls2[i * 3 + 2]
            ls3.extend([t[x4], t[x5], t[x6], t[x7]])
    t2 = ''.join(ls3).replace("/", "")
    sign = "zzb" + (t1 + t2 + t3).lower()
    return sign


class Music:
    def __init__(self, info):
        self.info = info

        self.qm_keyst = None
        self.cookies = None
        self.uin = info.uin
        self.client_key = info.cookies.client_key
        self.code = None
        self.g_tk = None
        self.psrf_qqopenid = None

    def get_Location_code(self):
        if not self.client_key:
            return {'status': False, 'message': '没有获取到clientkey'}
        try:
            response = requests.get(url="https://ssl.ptlogin2.qq.com/jump",
                                    params={
                                        "keyindex": "19",
                                        "clientuin": self.uin,
                                        "clientkey": self.client_key,
                                        "u1": "https://connect.qq.com",
                                        "pt_report": "1",
                                        "pt_aid": "716027609",
                                        "daid": "383",
                                        "style": "35",
                                        "pt_ua": "76BA0A6746DFE83A98D8D2F11E2D88FF",
                                        "pt_browser": "others",
                                        "pt_3rd_aid": "100497308",
                                        'pt_openlogin_data': f'appid=716027609&pt_3rd_aid=100497308&daid=383&pt_skey_valid=1&style=35&s_url=https%3A%2F%2Fconnect.qq.com&refer_cgi=authorize&which=&sdkp=pcweb&sdkv=v1.0&time={str(int(time.time()))}&loginty=3&h5sig=eGKHXAcp1AAAlR38DBo6E_oj3OrsS53GtW1_bmkcOzY&response_type=code&client_id=100497308&redirect_uri=https%3A%2F%2Fy.qq.com%2Fm%2Flogin%2Fredirect.html%3Fis_qq_connect%3D1%26login_type%3D1%26surl%3Dhttps%253A%252F%252Fi.y.qq.com%252Fn2%252Fm%252Fclient%252Factcenter%252Findex.html%253Ffrom_tag%253Dqq%2526openid%253D&state=state&display=mobile&scope=get_user_info%2Cget_app_friends&pt_flex=1&loginfrom=&h5sig=eGKHXAcp1AAAlR38DBo6E_oj3OrsS53GtW1_bmkcOzY&loginty=3&'
                                    }
                                    ,
                                    allow_redirects=False,
                                    proxies=self.info.proxy_proxies)
            Location = response.headers['Location']
            if Location is None:
                return {'status': False, 'message': '没找到Location'}
            parsed_url = urlparse(Location)
            query_params = parse_qs(parsed_url.query)
            self.code = query_params.get('code')[0]
            if self.code is None:
                return {'status': False, 'message': '没找到code'}
            return {'status': True, 'code': self.code}
        except Exception as e:
            return {'status': False, 'message': f'获取code异常{e}'}

    def get_cookie(self):
        try:
            post_data = {
                "comm": {"ct": 23, "cv": 0, "g_tk": 5381, "platform": "h5"},
                "req": {
                    "module": "QQConnectLogin.LoginServer",
                    "method": "QQLogin",
                    "param": {"code": self.code}
                }
            }
            post_json = json.dumps(post_data)

            rsp = requests.post(
                url='https://u.y.qq.com/cgi-bin/musicu.fcg',
                data=post_json,
                allow_redirects=False,
                proxies=self.info.proxy_proxies
            )

            self.cookies = '; '.join([f'{c.name}={c.value}' for c in rsp.cookies])
            self.qm_keyst = re.search(r'qm_keyst=([^;]+)', self.cookies).group(1)
            self.g_tk = qq_bkn(self.qm_keyst)
            self.psrf_qqopenid = rsp.cookies.get('psrf_qqopenid')
            return {'status': True}
        except Exception as e:
            return {'status': False, 'message': f'获取cookie异常{e}'}

    def get_tasks(self):
        if not all([self.psrf_qqopenid, self.g_tk, self.qm_keyst]):
            return {'status': False, 'message': '获得任务参数不全。'}
        urls = ['https://u6.y.qq.com/cgi-bin/musicu.fcg', 'https://u6.y.qq.com/cgi-bin/musics.fcg']
        try:
            for url in urls:
                # url = "https://u6.y.qq.com/cgi-bin/musics.fcg"
                data = {
                    "comm": {
                        "g_tk": self.g_tk,
                        "uin": int(self.uin),
                        "format": "json",
                        "inCharset": "utf-8",
                        "outCharset": "utf-8",
                        "notice": 0,
                        "platform": "h5",
                        "needNewCode": 1
                    },
                    "req_0": {
                        "module": "music.activeCenter.ActiveCenterZoneSvr",
                        "method": "QQTrans",
                        "param": {
                            "openid": self.psrf_qqopenid
                        }
                    }
                }

                data = json.dumps(data, separators=(',', ':'))
                querystring = {"_webcgikey": "QQTrans",  # 任务名
                               "_": int(time.time() * 1000),
                               "sign": music_sign(data)}

                headers = {
                    "Host": "u6.y.qq.com",
                    "Accept": "application/json",
                    "Sec-Fetch-Site": "same-site",
                    "Accept-Language": "zh-CN,zh-Hans;q=0.9",
                    "Sec-Fetch-Mode": "cors",
                    "Origin": "https://y.qq.com",
                    "User-Agent": User_Agent,
                    "Referer": "https://y.qq.com/",
                    "Sec-Fetch-Dest": "empty",
                    "Connection": "close",
                    "Cookie": self.cookies,
                    "Content-Type": "application/json"
                }

                response = requests.request("POST", url,
                                            params=querystring,
                                            data=data,
                                            headers=headers,
                                            proxies=self.info.proxy_proxies

                                            )

                code = response.json()['code']
                if code != 0:
                    return {'status': False, 'code': code, 'message': '获取任务失败'}
                return {'status': True, 'code': code, 'message': '获取任务失败'}


        except Exception as e:
            return {'status': False, 'message': f'获取任务异常{e}'}

    def play_music(self):
        succNum = 0
        songs = [323403041, 127112164, 126734700, 127072327, 1864367, 1864181, 1863217, 237878389, 249657523, 251434247,
                 127096234, 127084627]
        try:
            for i in range(10):
                opTime = str(int(time.time()))
                songid = 264349097
                random_song = random.choice(songs)

                songTime = 1800 + random.randint(0, 27)  # 音乐时长，越大成功几率越低 300-1800

                timeKey = hashlib.md5((opTime + str(songTime) + self.uin + "gk2$Lh-&l4#!4iow").encode()).hexdigest()
                # uid 音乐 id 随机更好
                uid = 4969525851 + random.randint(0, 5000)
                xml = f"""<?xml version="1.0" encoding="UTF-8"?>
                <root>
                    <ct>11</ct>
                    <cv>13030008</cv>
                    <v>13030008</v>
                    <uid>{uid}</uid>
                    <qq>{self.uin}</qq>
                    <authst>{self.qm_keyst}</authst>
                    <item cmd="1" uid="{uid}" optime="{opTime}" time="{songTime}" timekey="{timeKey}" QQ="{self.uin}" songid="{random_song}"/>
                </root>"""

                gzip_buffer = BytesIO()
                with gzip.GzipFile(mode='wb', fileobj=gzip_buffer) as gzip_file:
                    gzip_file.write(xml.encode('utf-8'))
                compressed_xml = gzip_buffer.getvalue()

                response = requests.post(
                    url='https://stat6.y.qq.com/android/fcgi-bin/imusic_tj',
                    headers={
                        'User-Agent': 'QQMusic 13030008(android 10)',
                        'Content-Encoding': 'gzip',
                    },
                    data=compressed_xml,
                    proxies=self.info.proxy_proxies

                )
                if response.status_code == 200:
                    body = response.content
                    if body and body[-1] == 0xD7:
                        succNum += 1
                if succNum >= 1:
                    break

            if succNum >= 1:
                return {'status': True, 'message': '播放成功'}
            else:
                return {'status': False, 'message': '播放失败'}

        except Exception as e:
            return {'status': False, 'message': f'播放异常:{e}'}

    def task(self):
        # 结束需要通过 获取账号页面确认
        for func in [self.get_Location_code, self.get_cookie, self.get_tasks, self.play_music]:
            rsp = func()
            if not rsp['status']:
                return rsp
        return rsp


def de_gzip(data):
    compressed_xml = bytes.fromhex(data)

    # 使用 BytesIO 创建一个内存中的文件对象，用于读取压缩的数据
    gzip_buffer = BytesIO(compressed_xml)

    # 使用 GzipFile 对象来读取和解压 gzip 数据
    with gzip.GzipFile(mode='rb', fileobj=gzip_buffer) as gzip_file:
        decompressed_xml = gzip_file.read()

    # 解压后的 XML 数据，现在是 utf-8 编码的字节串，可以根据需要解码
    xml = decompressed_xml.decode('utf-8')

    print(xml)  # 打印解压后的 XML 字符串


if __name__ == '__main__':
    de_gzip('00000000007801ab564ace4f4955b2523050d051ca2d4e57b25252aa55000047ca05d7')
    pass
    # music = Music()
    # print(music.task())



from pyproto import ProtoBuf

from AndroidQQ.struct import PackHeadNoToken, Pack_


def OidbSvc_0xdfa_0(info):
    # buffer = ProtoBuf({2: 0,
    #                    3: '{"stsetgxhreq":{"appid":23,"itemid":0,"opplat":2,"qqver":"8.9.83","hashid":"D26F32B308A52FA81C0710010701ED17"},"cmd":6}'}).toBuf()

    buffer = bytes.fromhex('08 00 01 06 04 72 65 73 70 1D 00 00 39 0A 02 0D 80 F2 07 19 00 01 0A 02 0D 80 F2 07 1C 21 4D 57 3D 00 00 13 08 90 04 10 92 8F E6 DB 83 80 80 80 02 18 00 20 E0 86 03 4C 5C 6C 7C 8C 9C AC 0B 22 73 B0 95 09 4C 0B')

    buffer = PackHeadNoToken(info, buffer, 'OnlinePush.RespPush','OnlinePush','SvcRespPushMsg')
    buffer = Pack_(info, buffer, Types=11, encryption=1, sso_seq=info.seq)
    return buffer



import requests
from box import Box
from bs4 import BeautifulSoup


def parse_proxy_info(html_content):
    soup = BeautifulSoup(html_content, 'html.parser')
    div_tag = soup.find('div', class_='data kq-well')
    if div_tag:
        pre_tag = div_tag.find('pre')
        if pre_tag:
            pre_text = pre_tag.get_text()
            return pre_text
        else:
            return None
    else:
        return None


def _get_ip_ipinfo(proxy_proxies=None) -> Box:
    """ipinfo.io"""
    try:
        rsp = requests.get('https://ipinfo.io/json',
                           timeout=3,
                           proxies=proxy_proxies
                           )
        if rsp.status_code == 200:
            data = rsp.json()
            ip = data.get('ip')
            region = data.get('region')
            country = data.get('country')
            city = data.get('city')
            org = data.get('org')
            return Box(status=True, ip=ip, 地区=region, 国家=country, 城市=city, org=org)
        else:
            return Box(status=False, ip='0.0.0.0', error=str(rsp.status_code))
    except Exception as e:
        return Box(status=False, ip='0.0.0.0', error=str(e))


def _get_ip_api(proxy_proxies=None) -> Box:
    try:
        rsp = requests.get('http://ip-api.com/json/?lang=zh-CN',
                           timeout=3,
                           proxies=proxy_proxies
                           )
        if rsp.status_code == 200:
            data = rsp.json()
            ip = data.get('query')
            country = data.get('country')
            region = data.get('regionName')
            city = data.get('city')
            org = data.get('as')
            return Box(status=True, ip=ip, 地区=region, 国家=country, 城市=city, org=org)
        else:
            return Box(status=False, ip='0.0.0.0', error=str(rsp.status_code))
    except Exception as e:
        return Box(status=False, ip='0.0.0.0', error=str(e))


def _get_ip_ipapi(proxy_proxies=None) -> Box:
    try:
        rsp = requests.get('https://ipapi.co/json/',
                           timeout=3,
                           proxies=proxy_proxies
                           )
        if rsp.status_code == 200:
            data = rsp.json()
            ip = data.get('ip', '0.0.0.0')
            region = data.get('region', None)
            country = data.get('country', None)
            city = data.get('city', None)
            org = data.get('org', None)
            return Box(status=True, ip=ip, 地区=region, 国家=country, 城市=city, org=org)
        else:
            return Box(status=False, ip='0.0.0.0', error=str(rsp.status_code))
    except Exception as e:
        return Box(status=False, ip='0.0.0.0', error=str(e))


def _get_cip(proxy_proxies=None):
    """获取http代理ip"""
    try:
        rsp = requests.get('https://cip.cc',
                           timeout=3,
                           proxies=proxy_proxies
                           )
        proxy_info = parse_proxy_info(rsp.content)
        if proxy_info:
            return proxy_info
        else:
            return None
    except Exception as e:
        print(f'获取http代理ip失败:{e}')
        return None


def GetHttpIp(proxy_proxies=None):
    """获取http代理ip"""
    ip_api_list = [_get_ip_ipinfo, _get_ip_api, _get_ip_ipapi]
    for ip_api in ip_api_list:
        ip_info = ip_api(proxy_proxies)
        if ip_info.status:
            ip_info.api_name = ip_api.__name__
            ip_info.index = ip_api_list.index(ip_api)
            return ip_info


if __name__ == '__main__':
    print(GetHttpIp())
    pass



from typing import Union

from Jce_b import JceReader, IJceStruct


class QQHeadInfo(IJceStruct):
    apngFaceFlag: int = 0  # 使用 int 替代 Java 的 byte
    cHeadType: int = 0
    downLoadUrl: str = ""
    dstUsrType: int = 0
    dwFaceFlgas: int = 0
    dwTimestamp: int = 0  # 使用 int 替代 Java 的 long
    headLevel: int = 0
    headVerify: str = ""
    idType: int = 0
    originUsrType: int = 0
    phoneNum: str = ""
    sizeType: int = 0
    systemHeadID: int = 0  # 使用 int 替代 Java 的 short
    uin: int = 0

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass

    def read_from(self, reader: JceReader) -> None:
        self.uin = reader.read_int64(0)
        self.dwTimestamp = reader.read_int64(1)
        self.cHeadType = reader.read_int32(2)
        self.dstUsrType = reader.read_int32(3)
        self.dwFaceFlgas = reader.read_int64(4)
        self.downLoadUrl = reader.read_string(5)
        self.systemHeadID = reader.read_int64(6)
        self.phoneNum = reader.read_string(7)
#       实践还返回了一个8



# struct AvatarInfo;
from typing import List, Union, cast

from Jce_b import JceReader, IJceStruct

from AndroidQQ.struct.Avatarlnfo.QQHeadInfo import QQHeadInfo


class QQHeadUrlResp(IJceStruct):
    UserHeadInfoList: List[QQHeadInfo] = []  # 使用 List 替代 Java 的 ArrayList
    myUin: int = 0
    result: int = 0

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass

    def read_from(self, reader: JceReader) -> None:
        self.myUin = reader.read_int64(0)
        self.result = reader.read_int32(1)
        self.UserHeadInfoList = cast(List[QQHeadInfo], reader.read_list(QQHeadInfo, 2))

    def to_dict(self) -> dict:
        return self.__dict__



import json
from random import randint

from AndTools import pack_b, get_random_bin, TEA
from Jce_b import JceWriter, JceReader
from pyproto import ProtoBuf

from AndroidQQ import log


def Pack_(info, data, Types, encryption, sso_seq=None, token=False):
    """组包
    Types:包类型  通常是10 和11
    encryption  加密方式   2 不需要token  1需要token
    sso_seq 包序号
    """
    Pack = pack_b()
    Pack.add_int(Types)
    Pack.add_bytes(encryption)
    if not info.uin:
        Uin_bytes = bytes.fromhex('30')
    else:
        Uin_bytes = info.uin.encode('utf-8')

    if token:
        D2 = info.UN_Tlv_list.D2_T143
        Pack.add_int(len(D2) + 4)
        Pack.add_bin(D2)

    if sso_seq is not None:
        Pack.add_int(sso_seq)
    Pack.add_bytes(0)

    Pack.add_int(len(Uin_bytes) + 4)
    Pack.add_bin(Uin_bytes)
    Pack.add_bin(data)
    bytes_temp = Pack.get_bytes()

    Pack.empty()
    Pack.add_int(len(bytes_temp) + 4)
    Pack.add_bin(bytes_temp)
    return Pack.get_bytes()


def Pack_Head(info, data, Cmd):
    """包头"""
    TokenA4 = info.UN_Tlv_list.TGT_T10A
    if TokenA4 is None:
        TokenA4 = b''

    Pack = pack_b()
    Pack.add_int(info.seq)
    Pack.add_int(info.device.app_id)
    Pack.add_int(info.device.app_id)

    Pack.add_Hex('01 00 00 00')
    Pack.add_Hex('00 00 00 00')
    Pack.add_Hex('00 00 01 00')
    Pack.add_int(len(TokenA4) + 4)
    Pack.add_bin(TokenA4)
    Pack.add_int(len(Cmd) + 4)
    Pack.add_bin(bytes(Cmd, 'utf-8'))
    Pack.add_Hex('00 00 00 08')
    Pack.add_bin(get_random_bin(4))

    Pack.add_body(info.device.Imei, 4, add_len=4)
    Pack.add_Hex('00 00 00 04')

    Pack.add_body(info.device.var, 2, add_len=2)

    bytes_temp = Pack.get_bytes()

    Pack.empty()
    Pack.add_int(len(bytes_temp) + 4)
    Pack.add_bin(bytes_temp)
    bytes_temp = Pack.get_bytes()

    Pack.empty()
    Pack.add_bin(bytes_temp)
    Pack.add_int(len(data) + 4)
    Pack.add_bin(data)
    bytes_temp = Pack.get_bytes()
    bytes_temp = TEA.encrypt(bytes_temp, info.share_key)
    return bytes_temp


def Pack_Head_login_test(info, Cmd, data_02):
    """返回前面的头,后面的单独写在组包的函数里面
    01 8C
    1F 41
    08 12
    """
    pack = pack_b()
    pack.add_int(info.seq)
    pack.add_int(info.device.app_id)
    pack.add_int(info.device.app_id)
    pack.add_Hex('01 00 00 00 00 00 00 00 00 00 03 00')
    pack.add_int(len(info.UN_Tlv_list.T10A_token_A4) + 4)
    pack.add_bin(info.UN_Tlv_list.T10A_token_A4)
    pack.add_int(len(Cmd.encode('utf-8')) + 4)
    pack.add_bin(Cmd.encode('utf-8'))

    pack.add_Hex('00 00 00 08')
    pack.add_bin(get_random_bin(4))

    pack.add_int(len(info.device.IMEI) + 4)
    pack.add_bin(info.device.IMEI)

    pack.add_Hex('00 00 00 04')

    pack.add_int(len(info.device.var) + 2, 2)
    pack.add_bin(info.device.var)

    # 增加的
    _dict = {9: 1, 11: 2052, 12: '08c7f955ce81db0cca48bca510001751740b', 14: 0, 16: '', 18: 0, 19: 1, 20: 1, 21: 0,
             23: {1: 'client_conn_seq', 2: '1691763088'},
             24: {1: bytes.fromhex(
                 '0C0B2A074B060DD4D8EA163940EE2E66347704F2157B4A556F283E0671E4E33796ABEE4DF07BC5B8DB14DFA63CFAF1F66483C729DCC38EF9F7DE844FE9D9A30B'),
                 2: 'fDjMVp3pEqXt',
                 3: {2: 'V1_AND_SQ_8.9.71_4332_YYB_D',
                     3: 'X_LuHJtftAAPTwFk9SOftIHXmx2mCAL19e+MiYSrIXopqlBkJKOqC9fu2qT0j1lmIy/f7TAWpLSZclldF6w8JzWj6vYSqzd9s='}},
             26: 100, 28: 2}

    data_temp = ProtoBuf(_dict).toBuf()

    pack.add_int(len(data_temp) + 4)
    pack.add_bin(data_temp)
    bytes_temp = pack.get_bytes()

    pack.empty()
    pack.add_int(len(bytes_temp) + 4)
    pack.add_bin(bytes_temp)

    data_head = pack.get_bytes()

    pack.empty()
    pack.add_int(len(data_02) + 4)
    pack.add_bin(data_02)
    data_02 = pack.get_bytes()

    data = data_head + data_02
    # 02
    # 01 8C

    data = TEA.encrypt(data, '00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00')

    return data


def Pack_Head_login(info, Cmd, Buffer):
    """返回前面的头,后面的单独写在组包的函数里面
    01 8C
    1F 41
    08 12
    """
    pack = pack_b()
    pack.add_int(info.seq)
    pack.add_int(info.device.app_id)
    pack.add_int(info.device.app_id)
    pack.add_Hex('01 00 00 00 00 00 00 00 00 00 01 00')
    pack.add_body(info.UN_Tlv_list.TGT_T10A, 4, add_len=4)
    pack.add_body(Cmd, 4, add_len=4)
    pack.add_body(get_random_bin(4), length=4, add_len=4)  # MsgCookies
    pack.add_body(info.device.Imei, 4, add_len=4)
    pack.add_Hex('00 00 00 04')
    pack.add_body(info.device.var, 2, add_len=2)
    bytes_temp = pack.get_bytes()

    pack.empty()
    pack.add_body(bytes_temp, 4, add_len=4)
    pack.add_body(Buffer, 4, add_len=4)
    data = pack.get_bytes()
    data = TEA.encrypt(data, '00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00')
    return data


def PackHeadNoToken(info, sBuffer, serviceCmd, sServantName=None, sFuncName=None):
    """照抄的旧源码"""
    # struct com.qq.taf;

    if sServantName is not None:
        """jce部分"""
        iRequestId = randint(110000000, 999999999)
        jce = JceWriter()
        jce.write_int32(3, 1)  # iVersion
        jce.write_int32(0, 2)  # cPacketType
        jce.write_int32(0, 3)  # iMessageType
        jce.write_int64(iRequestId, 4)
        jce.write_string(sServantName, 5)
        jce.write_string(sFuncName, 6)
        jce.write_bytes(sBuffer, 7)
        jce.write_int32(0, 8)  # iTimeout
        _data = jce.bytes()
        _data = _data + bytes.fromhex('98 0C A8 0C')  # 后面的两个空的
    else:
        _data = sBuffer

    pack = pack_b()
    pack.add_int(len(serviceCmd) + 4)
    pack.add_bin(bytes(serviceCmd, 'utf-8'))
    pack.add_Hex('00 00 00 08')
    pack.add_bin(get_random_bin(4))
    pack.add_Hex('00 00 00 04')
    _data_temp = pack.get_bytes()

    pack.empty()
    pack.add_int(len(_data_temp) + 4)
    pack.add_bin(_data_temp)
    _data_temp = pack.get_bytes()

    pack.empty()
    pack.add_bin(_data_temp)
    pack.add_int(len(_data) + 4)
    pack.add_bin(_data)
    _data = pack.get_bytes()
    _data = TEA.encrypt(_data, info.share_key)

    return _data


def PackHead_QMF(info, serviceCmd, Upstream):
    """缝补补,又一年"""
    pack = pack_b()
    pack.add_int(len(serviceCmd) + 4)
    pack.add_bin(bytes(serviceCmd, 'utf-8'))
    pack.add_Hex('00 00 00 08')
    pack.add_bin(get_random_bin(4))
    pack.add_Hex('00 00 00 04')
    _data_temp = pack.get_bytes()

    pack.empty()
    pack.add_int(len(_data_temp) + 4)
    pack.add_bin(_data_temp)
    _data_temp = pack.get_bytes()

    pack.empty()
    pack.add_bin(_data_temp)
    pack.add_int(len(Upstream) + 4)
    pack.add_bin(Upstream)
    _data = pack.get_bytes()

    Buffer = TEA.encrypt(_data, info.share_key)

    Buffer = Pack_(info, Buffer, Types=11, encryption=1, sso_seq=info.seq)

    return Buffer


def Un_jce_Head(data) -> bytes:
    jce = JceReader(data)
    jce.read_int32(1)
    jce.read_int32(2)
    jce.read_int32(3)
    jce.read_int64(4)
    jce.read_string(5)
    jce.read_string(6)
    data = jce.read_any(7)
    return data


def Un_jce_Head_2(data) -> bytes:
    """Map"""
    jce = JceReader(data)
    jce.skip(1)  # ReadType
    jce.skip(2)  # ReadShort
    jce.read_string(0)
    jce.skip(1)  # ReadType
    jce.skip(2)  # ReadShort
    jce.read_string(0)
    data = jce.read_any(1)

    return data



from typing import Union

from Jce_b import IJceStruct, JceWriter
from Jce_b.typing import JceReader


class UserLocaleInfo(IJceStruct):
    """用户区域设置信息"""
    Latitude: int = 0  # 纬度
    Longitude: int = 0  # 经度

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        jce = JceWriter()
        jce.write_int64(self.Longitude, 1)
        jce.write_int64(self.Latitude, 2)
        return jce.bytes()



import json
import re

import requests

from AndroidQQ.http import User_Agent
from AndroidQQ.utils import qq_bkn


def change_psw_getsms(info, Cookie: str, mobile: str):
    match = re.search(r'skey=([^;]+)', Cookie)
    if match:
        skey = match.group(1)
    else:
        skey = None

    try:

        Cookie = Cookie + 'domainid=761'
        response = requests.post(
            url="https://accounts.qq.com/v2/cn2/change_psw/proxy/domain/qq110.qq.com/v3/getsms",
            params={
                "bkn": qq_bkn(skey),
            },
            headers={
                "Host": "accounts.qq.com",
                "Connection": "keep-alive",
                "Content-Length": "109",
                "Accept": "application/json, text/plain, */*",
                "qname-service": "1935233:65536",
                "qname-space": "Production",
                "User-Agent": User_Agent,
                "Content-Type": "application/json",
                "Origin": 'https://accounts.qq.com',
                "X-Requested-With": "com.tencent.mobileqq",
                "Sec-Fetch-Site": "same-origin",
                "Sec-Fetch-Mode": "cors",
                "Sec-Fetch-Dest": "empty",
                "Referer": "https://accounts.qq.com/cn2/change_psw/mobile/mobile_change_psw_way?source_id=3259&uin=" + info.uin,
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
                "Cookie": Cookie,

            },
            data=json.dumps({
                "com": {
                    "version": "8.9.83",
                    "scene": 304,
                    "src": 1,
                    "platform": 2
                },
                "areaCode": "+86",
                "way": 3,
                "mobile": mobile
            }),
            proxies=info.proxy_proxies

        )

        return response.json()
    except requests.exceptions.RequestException:
        print('发送短信失败')
        return {}



import time

import requests


def ClientKeyToCookies(info, uin, client_key):
    try:
        response = requests.get(url="https://ssl.ptlogin2.qq.com/jump",
                                params={
                                    "keyindex": "19",
                                    "clientuin": uin,
                                    "clientkey": client_key,
                                    "u1": "https://connect.qq.com",
                                    "pt_report": "1",
                                    "pt_aid": "716027609",
                                    "daid": "383",
                                    "style": "35",
                                    "pt_ua": "60C3D6175A88C661094CF87DC58D1C55",
                                    "pt_browser": "others",
                                    "pt_3rd_aid": "1101083114",
                                    "pt_openlogin_data": f"appid=716027609&pt_3rd_aid=1101083114&daid=383&pt_skey_valid=0&style=35&s_url=https%3A%2F%2Fconnect.qq.com&refer_cgi=authorize&which=&sdkp=pcweb&sdkv=v1.0&time={str(int(time.time()))}&loginty=3&h5sig=OnX6dkcSfE3T5i4O7UxIp2gnmDJnviaXNxQcfA9X1Xg&response_type=code&client_id=1101083114&redirect_uri=https%3A%2F%2Fh5.weishi.qq.com%2Fweishi%2Faccount%2Flogin%3Fr_url%3Dhttp%253A%252F%252Fmedia.weishi.qq.com%252F%26loginfrom%3Dqc%26retry%3D1&state=state&pt_flex=1&loginfrom=&h5sig=OnX6dkcSfE3T5i4O7UxIp2gnmDJnviaXNxQcfA9X1Xg&loginty=3&",
                                }
                                ,
                                allow_redirects=False,
                                proxies=info.proxy_proxies
                                )
        Location = response.headers['Location']
        if Location is None:
            return {'status': False, 'message': '没找到Location'}
        response = requests.get(url=Location, allow_redirects=False, proxies=info.proxy_proxies
                                )
        cookie_str = '; '.join([f'{c.name}={c.value}' for c in response.cookies])

        return {'status': True, 'cookie': cookie_str}
    except Exception as e:
        return {'status': False, 'message': f'ClientKeyToCookies获取cookie异常:{e}'}



import setuptools

with open("requirements.txt", "r") as f:
    requirements = f.read().splitlines()
setuptools.setup(
    name='MBQQ',
    version='0.9.2',
    url='https://pypi.org/manage/account/token/',
    packages=setuptools.find_packages(exclude=["tests", "tests.*", "wiki", "wiki.*"]),
    license='',
    author='Magpie Bridge',
    author_email='',
    description='',
    install_requires=[
        'MDQTools',
        'protobuf==4.23.4',
        'pydantic==2.1.1',
        'cryptography',
        'bs4',
        'urllib3==1.26.16',
        'pydantic',
        'requests',
        'python-box',
        'PySocks',
        'python-box',
        'loguru'

    ]

)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AndroidQQ/im/oidb/qqconnect/qqconnect.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+AndroidQQ/im/oidb/qqconnect/qqconnect.proto\x12\x0ftencent.im.oidb\"\xbf\x01\n\x12TencentDocsAppinfo\x12\x12\n\nopen_types\x18\x01 \x01(\t\x12\x0c\n\x04opts\x18\x02 \x01(\t\x12\x0b\n\x03\x65js\x18\x03 \x01(\t\x12\x19\n\x11\x63\x61llback_url_test\x18\x04 \x01(\t\x12\x14\n\x0c\x63\x61llback_url\x18\x05 \x01(\t\x12\x0e\n\x06\x64omain\x18\x06 \x01(\t\x12\x19\n\x11userinfo_callback\x18\x07 \x01(\t\x12\x1e\n\x16userinfo_callback_test\x18\x08 \x01(\t\"\xc6\x04\n\x07\x41ppinfo\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x61pp_type\x18\x02 \x01(\r\x12\x10\n\x08platform\x18\x03 \x01(\r\x12\x10\n\x08\x61pp_name\x18\x04 \x01(\t\x12\x0f\n\x07\x61pp_key\x18\x05 \x01(\t\x12\x11\n\tapp_state\x18\x06 \x01(\r\x12\x19\n\x11iphone_url_scheme\x18\x07 \x01(\t\x12\x19\n\x11\x61ndroid_pack_name\x18\x08 \x01(\t\x12\x10\n\x08icon_url\x18\t \x01(\t\x12\x12\n\nsource_url\x18\n \x01(\t\x12\x16\n\x0eicon_small_url\x18\x0b \x01(\t\x12\x17\n\x0ficon_middle_url\x18\x0c \x01(\t\x12\x41\n\x14tencent_docs_appinfo\x18\r \x03(\x0b\x32#.tencent.im.oidb.TencentDocsAppinfo\x12\x15\n\rdeveloper_uin\x18\x15 \x01(\x04\x12\x11\n\tapp_class\x18\x16 \x01(\r\x12\x14\n\x0c\x61pp_subclass\x18\x17 \x01(\r\x12\x0e\n\x06remark\x18\x18 \x01(\t\x12\x15\n\ricon_mini_url\x18\x19 \x01(\t\x12\x11\n\tauth_time\x18\x1a \x01(\x04\x12\x0f\n\x07\x61pp_url\x18\x1b \x01(\t\x12\x16\n\x0euniversal_link\x18\x1c \x01(\t\x12\x19\n\x11qqconnect_feature\x18\x1d \x01(\r\x12\x13\n\x0bis_hatchery\x18\x1e \x01(\x05\x12\x1b\n\x13\x65\x64it_universal_link\x18  \x01(\t\x12\x12\n\ncompany_id\x18! \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AndroidQQ.im.oidb.qqconnect.qqconnect_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TENCENTDOCSAPPINFO']._serialized_start=65
  _globals['_TENCENTDOCSAPPINFO']._serialized_end=256
  _globals['_APPINFO']._serialized_start=259
  _globals['_APPINFO']._serialized_end=841
# @@protoc_insertion_point(module_scope)



# package NS_MOBILE_OPERATION;
from typing import Any, Union

from Jce_b import IJceStruct, JceWriter
from Jce_b.typing import JceReader


class operation_delugc_req(IJceStruct):
    appid: int = 0
    busi_param: dict = None
    content: str = ''
    isverified: int = 0
    mapEx: dict = None
    ownuin: int = 0
    srcId: str = ''
    srcSubid: str = ''
    uin: int = 0

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        jce = JceWriter()
        jce.write_object(self.appid, 0)
        jce.write_object(self.uin, 1)
        jce.write_object(self.ownuin, 2)
        if self.srcId:
            jce.write_object(self.srcId, 3)

        if self.srcSubid:
            jce.write_object(self.srcSubid, 4)
        if self.content:
            jce.write_object(self.content, 5)

        jce.write_object(self.isverified, 6)
        jce.write_object(self.mapEx, 8)

        return jce.bytes()


if __name__ == '__main__':
    print(operation_delugc_req(
        appid=311,
        uin=3810573312,
        ownuin=3810573312,
        srcId='00bc20e3821cc365e3e20100'

    ).to_bytes().hex())



# package NS_MOBILE_OPERATION;
from typing import Any, Union

from Jce_b import IJceStruct, JceWriter
from Jce_b.typing import JceReader


class operation_like_req(IJceStruct):
    action: int = 0
    appid: int = 0
    busi_param: dict = None
    bypass_param: dict = None
    bypass_param_binary: bytes = None
    curkey: str = ""
    extern_param: dict = None
    hostuin: int = 0
    uin: int = 0
    unikey: str = ""

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        jce = JceWriter()
        jce.write_object(self.uin, 0)
        if self.curkey is not None:
            jce.write_object(self.curkey, 1)

        if self.unikey is not None:
            jce.write_object(self.unikey, 2)

        jce.write_object(self.action, 3)
        jce.write_object(self.appid, 4)
        if self.busi_param is not None:
            jce.write_map(self.busi_param, 5)

        jce.write_object(self.hostuin, 6)

        if self.extern_param is not None:
            jce.write_object(self.extern_param, 7)
        if self.bypass_param is not None:
            jce.write_object(self.bypass_param, 8)
        if self.bypass_param_binary is not None:
            jce.write_object(self.bypass_param_binary, 9)

        return jce.bytes()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AndroidQQ/im/oidb/cmd0x922/PushInfo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)AndroidQQ/im/oidb/cmd0x922/PushInfo.proto\x12\x10im.oidb.cmd0x922\"\x94\x01\n\x08PushInfo\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x11\n\tred_point\x18\x02 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\r\x12\x0e\n\x06prompt\x18\x04 \x01(\x0c\x12\x0b\n\x03url\x18\x05 \x01(\x0c\x12\x10\n\x08icon_url\x18\x06 \x01(\x0c\x12\x18\n\x10lst_checkin_time\x18\x07 \x01(\r\x12\x11\n\topen_func\x18\x08 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AndroidQQ.im.oidb.cmd0x922.PushInfo_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PUSHINFO']._serialized_start=64
  _globals['_PUSHINFO']._serialized_end=212
# @@protoc_insertion_point(module_scope)



# friendlist 好友列表
from Jce import JceInputStream, JceStruct
from Jce_b import JceWriter

from AndroidQQ.struct import PackHeadNoToken, Pack_, Un_jce_Head, Un_jce_Head_2


def GetSimpleOnlineFriendInfoReq(info=None, **kwargs):
    """"获取简单好友列表"""
    jce = JceWriter()
    jce.write_int64(int(info.uin), 0)
    jce.write_bool(kwargs.get('ifgetFriendVideoAbi', False), 1)  # 是否获取朋友的视频能力
    jce.write_bool(kwargs.get('isReqCheckIn', False), 2)  # 是否请求签到
    jce.write_bool(kwargs.get('ifShowTermType', True), 4)  # 是否显示好友的设备类型
    jce.write_int32(kwargs.get('version', 33), 5)  # 版本号
    jce.write_int32(kwargs.get('cSrcType', 1), 6)  # 来源类型
    _data = jce.bytes()
    _data = JceWriter().write_jce_struct(_data, 0)
    _data = JceWriter().write_map({'FSOLREQ': _data}, 0)
    _data = PackHeadNoToken(info, _data, 'friendlist.GetSimpleOnlineFriendInfoReq',
                            'mqq.IMService.FriendListServiceServantObj', 'GetSimpleOnlineFriendInfoReq')
    _data = Pack_(info, _data, Types=11, encryption=1, sso_seq=info.seq)
    return _data


def GetSimpleOnlineFriendInfoReq_res(data):
    """获取简单好友列表"""
    data = Un_jce_Head(data)
    data = data[18:]
    stream = JceInputStream(data)
    jce = JceStruct()
    jce.read_from(stream)
    return jce.to_json()



from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader


class operation_publishmood_rsp(IJceStruct):
    msg: str = ""
    ret: int = 0
    tid: str = ""
    verifyurl: str = ""  # 验证者

    def read_from(self, reader: JceReader) -> None:
        self.ret = reader.read_any(0)
        self.verifyurl = reader.read_any(1)
        self.tid = reader.read_any(2)
        self.msg = reader.read_any(3)

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass



import json
import requests

from AndroidQQ.http import User_Agent
from AndroidQQ.http.ClientKey import ClientKeyToCookies


def weishi_up_(info):
    if not info.cookies.client_key:
        return {'status': False, 'message': '没有获取到clientkey'}

    rsp = ClientKeyToCookies(info, info.uin, info.cookies.client_key)
    if not rsp['status']:
        return rsp
    try:
        cookies = rsp['cookie']
        params = {
            "req_body": {
                "blockID": "2",
                "bizPayload": "{\"taskId\":\"\"}"
            }
        }
        params = json.dumps(params)

        rsp = requests.post(
            url='https://api.weishi.qq.com/trpc.weishi.weishi_h5_proxy.weishi_h5_proxy/WelfareBlockObtain',
            params=params,
            headers={
                "User-Agent": User_Agent,
                "Content-Type": "multipart/form-data",
                "Origin": "https://isee.weishi.qq.com",
                "Referer": "https://isee.weishi.qq.com/",
                "Cookie": cookies,
                "wesee_fe_map_ext": "{}",
            },
            proxies=info.proxy_proxies

        )
        return {'status': True, 'rsp': rsp.json()}
    except Exception as e:
        return {'status': False, 'message': f'微视任务失败{e}'}


if __name__ == '__main__':
    pass



from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader


class s_picurl(IJceStruct):
    enlarge_rate: int = 200
    focus_x: int = 0
    focus_y: int = 0
    height: int = 0
    md5: str = ""
    size: int = 0
    url: str = ""
    width: int = 0

    def read_from(self, reader: JceReader) -> None:
        self.url = reader.read_any(0)
        self.width = reader.read_any(1)
        self.height = reader.read_any(2)
        self.focus_x = reader.read_any(3)
        self.focus_y = reader.read_any(4)
        self.enlarge_rate = reader.read_any(5)
        self.size = reader.read_any(6)
        self.md5 = reader.read_any(7)

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass
